@@ -107,7 +107,7 @@ class RoleController(BaseController):
             self.authz.set_group(rolename, member_list, autodrop=autodrop)
             self.authz.save(revision, comment=log_message)
         except Exception, e:
-            msg = get_unicode(e[0])
+            msg = except_to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -128,7 +128,7 @@ class RoleController(BaseController):
                 self.authz.del_group(rolename)
                 self.authz.save(revision, comment=log_message)
             except Exception, e:
-                msg = get_unicode(e[0])
+                msg = except_to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -149,7 +149,7 @@ class RoleController(BaseController):
             self.authz.add_alias(aliasname, username)
             self.authz.save(revision, comment=log_message)
         except Exception, e:
-            msg = get_unicode(e[0])
+            msg = except_to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -170,7 +170,7 @@ class RoleController(BaseController):
                 self.authz.del_alias(aliasname)
                 self.authz.save(revision, comment=log_message)
             except Exception, e:
-                msg = get_unicode(e[0])
+                msg = except_to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
