@@ -22,6 +22,8 @@ def setup_config(command, filename, section, vars):
         os.mkdir(here+'/config')
     if not os.path.exists(here+'/config/RCS'):
         os.mkdir(here+'/config/RCS')
+    if not os.path.exists(here+'/svnroot'):
+        os.mkdir(here+'/svnroot')
     filelist = ['svn.access', 'svn.passwd', 'localconfig.py']
     for f in filelist:
         src  = resource_filename('pysvnmanager', 'config/' + f+'.in')
